@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 10083 2017-07-04 08:36:29Z David $
+# $Id: StatisticsHandler.py 10149 2017-08-08 03:13:44Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-07-04 08:36:29 +0000 (週二, 04 七月 2017) $
-# $Revision: 10083 $
+# $Date: 2017-08-08 11:13:44 +0800 (Tue, 08 Aug 2017) $
+# $Revision: 10149 $
 
 from datetime import timedelta, datetime
 
@@ -42,13 +42,13 @@ def getDateRange(startDate, endDate):
     """
     if isinstance(startDate, str):
         if startDate != "NaN":
-            startDate = datetime.strptime(startDate, '%Y/%m/%d')
+            startDate = datetime.strptime(startDate, '%Y-%m-%d')
     if isinstance(endDate, str):
         if endDate != "NaN":
-            endDate = datetime.strptime(endDate, '%Y/%m/%d')
+            endDate = datetime.strptime(endDate, '%Y-%m-%d')
     
-    deltaDays = endDate - startDate
-    daysAmount = deltaDays.days
+    deltaDays = endDate - startDate 
+    daysAmount = deltaDays.days + 1
     
     def _createDate(daysAmount):
         days = [startDate.strftime('%Y-%m-%d')]
@@ -388,8 +388,8 @@ def getAllDataDate():
     lastDate = ContactMailingStatus.objects.order_by('-creation_date')[0
                ].creation_date
     
-    deltaDays= lastDate - firstDate
-    daysAmount = deltaDays.days       
+    deltaDays = lastDate - firstDate + timedelta(1)
+    daysAmount = deltaDays.days + 1    
     
     days = [firstDate.strftime('%Y-%m-%d')]
     for i in range(1, daysAmount):
@@ -530,7 +530,7 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
     allDates = sorted(dict(totalData).keys())
     for day in allDataDates._days:        
         if day not in allDates:
-            OrderedDict(totalData.append([day, getEmptyDataStructure()]))  
+            totalData.append([day, getEmptyDataStructure()])
 
     allContent = {}
     if dataType == 'number':
@@ -590,14 +590,14 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
     # -- get range date content start ------------------------------------------
     deltaDays = None
     startDate = reqestGetData.get('startDate', None)    
-    startDate = startDate.encode('ascii','ignore')
+    # startDate = allDataDates.startDate.encode('ascii','ignore')
     
     endDate = reqestGetData.get('endDate', None)
-    endDate = endDate.encode('ascii','ignore')
+    # endDate = allDataDates.endDate.encode('ascii','ignore')
     
     period = reqestGetData.get('period', 'week')    
     if period == 'week':
-        deltaDays = 7
+        deltaDays = 6
         endDate = datetime.now()        
         startDate = endDate - timedelta(days=deltaDays)
     elif period == 'month':
